@@ -6,11 +6,15 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..1\n"; }
+BEGIN {
+	$| = 1;
+	print "1..1\n";
+	use vars qw/$Response $Request $Server $Application $Session/;
+}
 END {print "not ok 1\n" unless $loaded;}
 use Win32::ASP;
 $loaded = 1;
-print "ok 1\n";
+print STDOUT "ok 1\n";
 
 ######################### End of black magic.
 
